Package: statTarget
Type: Package
Title: Statistical Analysis of Molecular Profiles
Version: 1.42.0
Author: Hemi Luan
Maintainer: Hemi Luan <hemi.luan@gmail.com>
Depends: R (>= 3.6.0)
Imports:
        randomForest,plyr,pdist,ROC,utils,grDevices,graphics,rrcov,stats,
        pls,impute
VignetteBuilder: knitr
Suggests: testthat, BiocStyle, knitr, rmarkdown
Description: A streamlined tool provides a graphical user interface for
    quality control based signal drift correction (QC-RFSC), integration of
    data from multi-batch MS-based experiments, and the
    comprehensive statistical analysis in metabolomics and proteomics.
License: LGPL (>= 3)
URL: https://stattarget.github.io
biocViews: ImmunoOncology, Metabolomics, Proteomics, Machine Learning,
        Lipidomics, MassSpectrometry, QualityControl, Normalization,
        QC-RFSC, ComBat, DifferentialExpression, BatchEffect,
        Visualization, MultipleComparison,Preprocessing, Software
RoxygenNote: 7.2.1
NeedsCompilation: no
BuildVignettes: true
git_url: https://git.bioconductor.org/packages/statTarget
git_branch: RELEASE_3_23
git_last_commit: 5012ea6
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
Packaged: 2026-04-28 23:40:20 UTC; biocbuild
Built: R 4.6.0; ; 2026-04-29 05:02:55 UTC; unix
