# Generated by roxygen2: do not edit by hand

export(mdsPlot)
export(predict_RF)
export(pvimPlot)
export(rForest)
export(shiftCor)
export(shiftCor_dQC)
export(statAnalysis)
import(impute)
import(pdist)
import(pls)
importFrom(ROC,AUC)
importFrom(ROC,rocdemo.sca)
importFrom(grDevices,col2rgb)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,colors)
importFrom(grDevices,dev.copy2pdf)
importFrom(grDevices,dev.new)
importFrom(grDevices,dev.off)
importFrom(grDevices,palette)
importFrom(grDevices,pdf)
importFrom(grDevices,rainbow)
importFrom(grDevices,rgb)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,box)
importFrom(graphics,boxplot)
importFrom(graphics,grid)
importFrom(graphics,hist)
importFrom(graphics,identify)
importFrom(graphics,layout)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,segments)
importFrom(graphics,strheight)
importFrom(graphics,strwidth)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(plyr,.)
importFrom(plyr,daply)
importFrom(plyr,rlply)
importFrom(randomForest,MDSplot)
importFrom(randomForest,importance)
importFrom(randomForest,randomForest)
importFrom(rrcov,plot)
importFrom(stats,aggregate)
importFrom(stats,binomial)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,cov.wt)
importFrom(stats,density)
importFrom(stats,ecdf)
importFrom(stats,glm)
importFrom(stats,lm)
importFrom(stats,loess)
importFrom(stats,median)
importFrom(stats,p.adjust)
importFrom(stats,pf)
importFrom(stats,prcomp)
importFrom(stats,predict)
importFrom(stats,qf)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,resid)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,shapiro.test)
importFrom(stats,t.test)
importFrom(stats,update)
importFrom(stats,var)
importFrom(stats,wilcox.test)
importFrom(utils,capture.output)
importFrom(utils,install.packages)
importFrom(utils,read.csv)
importFrom(utils,read.delim)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
importFrom(utils,write.csv)
importFrom(utils,write.table)
