library(testthat)
library(statTarget)
#library(statTarget)
datpath <- system.file("extdata",package = "statTarget")
samPeno <- paste(datpath,"MTBLS79_sampleList.csv", sep="/")
samFile <- paste(datpath,"MTBLS79.csv", sep="/")
file <- paste(datpath,"data_example_two_groups.csv", sep="/")
shiftCor(samPeno,samFile,Frule = 0.8,imputeM = "KNN")

#test_check("statTarget")
