#' @name statTarget-package
#' @aliases statTarget-package
#' @docType package
#' @title Statistical Analysis of Molecular Profiles
#' @description An streamlined tool provides graphical user interface 
#' for quality control based signal correction, integration of 
#' MS-based data from multiple batches, and the 
#' comprehensive statistical analysis for omics studies.
#' @details Package: statTarget
#' @details Type: package
#' @details License: LGPL (>= 3)
#' @author Hemi Luan
#' @author Maintainer: Hemi Luan hemi.luan@gmail.com
#' @return A description of statTarget. See the details at https://stattarget.github.io
statTarget <- function() {
    message(date(), "\nStart the statTarget GUI session by using 'statTargetGUI()' ")
}
